==> amarok_2.9.0.orig.tar.xz: amarok-2.9.0/src/browsers/BrowserCategoryListSortFilterProxyModel.h <==
/****************************************************************************************
 * Copyright (c) 2008 Mark Kretschmann <kretschmann@kde.org>                            *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#ifndef BROWSERCATEGORYLISTSORTFILTERPROXYMODEL_H
#define BROWSERCATEGORYLISTSORTFILTERPROXYMODEL_H

#include <QSortFilterProxyModel>

#include "core/meta/forward_declarations.h"

class BrowserCategoryListSortFilterProxyModel : public QSortFilterProxyModel
{
    public:
        BrowserCategoryListSortFilterProxyModel( QObject * parent = 0 );
        virtual ~BrowserCategoryListSortFilterProxyModel();
};

#endif

==> amarok_3.3.1.orig.tar.xz: amarok-3.3.1/src/browsers/BrowserCategoryListSortFilterProxyModel.h <==
/****************************************************************************************
 * Copyright (c) 2008 Mark Kretschmann <kretschmann@kde.org>                            *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#ifndef BROWSERCATEGORYLISTSORTFILTERPROXYMODEL_H
#define BROWSERCATEGORYLISTSORTFILTERPROXYMODEL_H

#include <QSortFilterProxyModel>

#include "core/meta/forward_declarations.h"

class BrowserCategoryListSortFilterProxyModel : public QSortFilterProxyModel
{
    Q_OBJECT
    public:
        explicit BrowserCategoryListSortFilterProxyModel( QObject * parent = nullptr );
        ~BrowserCategoryListSortFilterProxyModel() override;
};

#endif
